@@ -87,11 +87,16 @@ class Basics:
     ):
         # create_project接口创建新的Project
         try:
-            response = self.dh.create_project(
+            self.dh.create_project(
                 project_name=project_name,
                 comment=comment
             )
-            return response
+            res = {
+                "code": 0,
+                "message": "ok",
+                "data": ""
+            }
+            return res
         except ResourceExistException as e:
             showlog.warning(e.error_msg)
             return
@@ -588,7 +593,6 @@ def lazy_save(
     }
     try:
         while True:
-            showlog.info('正在保存数据到DataHub...')
             add_response = blob_records_add(
                 project_name=save_project_name,
                 topic_name=save_topic_name,
@@ -599,7 +603,6 @@ def lazy_save(
             )  # 以blob方式存储，更加灵活
             add_response_code = add_response.get('code')
             if add_response_code == 0:
-                showlog.info('保存成功')
                 return save_res
             elif add_response_code == 404:
                 message = add_response.get('message')
